@@ -3,13 +3,14 @@
 use glib::prelude::*;
 use glib::translate::*;
 
+use super::prelude::*;
 use gst::LoggableError;
 use gst_base::subclass::prelude::*;
 
 use crate::AudioRingBufferSpec;
 use crate::AudioSink;
 
-pub trait AudioSinkImpl: AudioSinkImplExt + BaseSinkImpl {
+pub trait AudioSinkImpl: AudioSinkImplExt + AudioBaseSinkImpl {
     fn close(&self, sink: &Self::Type) -> Result<(), LoggableError> {
         self.parent_close(sink)
     }
@@ -184,7 +185,7 @@ impl<T: AudioSinkImpl> AudioSinkImplExt for T {
 
 unsafe impl<T: AudioSinkImpl> IsSubclassable<T> for AudioSink {
     fn class_init(klass: &mut glib::Class<Self>) {
-        <gst_base::BaseSink as IsSubclassable<T>>::class_init(klass);
+        Self::parent_class_init::<T>(klass);
         let klass = klass.as_mut();
         klass.close = Some(audiosink_close::<T>);
         klass.delay = Some(audiosink_delay::<T>);
@@ -194,17 +195,13 @@ unsafe impl<T: AudioSinkImpl> IsSubclassable<T> for AudioSink {
         klass.write = Some(audiosink_write::<T>);
         klass.reset = Some(audiosink_reset::<T>);
     }
-
-    fn instance_init(instance: &mut glib::subclass::InitializingObject<T>) {
-        <gst_base::BaseSink as IsSubclassable<T>>::instance_init(instance);
-    }
 }
 
 unsafe extern "C" fn audiosink_close<T: AudioSinkImpl>(
     ptr: *mut ffi::GstAudioSink,
 ) -> glib::ffi::gboolean {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<AudioSink> = from_glib_borrow(ptr);
 
     gst::panic_to_error!(&wrap, imp.panicked(), false, {
@@ -221,7 +218,7 @@ unsafe extern "C" fn audiosink_close<T: AudioSinkImpl>(
 
 unsafe extern "C" fn audiosink_delay<T: AudioSinkImpl>(ptr: *mut ffi::GstAudioSink) -> u32 {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<AudioSink> = from_glib_borrow(ptr);
 
     gst::panic_to_error!(&wrap, imp.panicked(), 0, {
@@ -233,7 +230,7 @@ unsafe extern "C" fn audiosink_open<T: AudioSinkImpl>(
     ptr: *mut ffi::GstAudioSink,
 ) -> glib::ffi::gboolean {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<AudioSink> = from_glib_borrow(ptr);
 
     gst::panic_to_error!(&wrap, imp.panicked(), false, {
@@ -253,7 +250,7 @@ unsafe extern "C" fn audiosink_prepare<T: AudioSinkImpl>(
     spec: *mut ffi::GstAudioRingBufferSpec,
 ) -> glib::ffi::gboolean {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<AudioSink> = from_glib_borrow(ptr);
 
     let spec = &mut *(spec as *mut AudioRingBufferSpec);
@@ -274,7 +271,7 @@ unsafe extern "C" fn audiosink_unprepare<T: AudioSinkImpl>(
     ptr: *mut ffi::GstAudioSink,
 ) -> glib::ffi::gboolean {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<AudioSink> = from_glib_borrow(ptr);
 
     gst::panic_to_error!(&wrap, imp.panicked(), false, {
@@ -295,7 +292,7 @@ unsafe extern "C" fn audiosink_write<T: AudioSinkImpl>(
     length: u32,
 ) -> i32 {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<AudioSink> = from_glib_borrow(ptr);
     let data_slice = std::slice::from_raw_parts(data as *const u8, length as usize);
 
@@ -306,7 +303,7 @@ unsafe extern "C" fn audiosink_write<T: AudioSinkImpl>(
 
 unsafe extern "C" fn audiosink_reset<T: AudioSinkImpl>(ptr: *mut ffi::GstAudioSink) {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<AudioSink> = from_glib_borrow(ptr);
 
     gst::panic_to_error!(&wrap, imp.panicked(), (), {
