@@ -5,13 +5,14 @@ use std::mem;
 use glib::prelude::*;
 use glib::translate::*;
 
+use super::prelude::*;
 use gst::LoggableError;
 use gst_base::subclass::prelude::*;
 
 use crate::AudioRingBufferSpec;
 use crate::AudioSrc;
 
-pub trait AudioSrcImpl: AudioSrcImplExt + BaseSrcImpl {
+pub trait AudioSrcImpl: AudioSrcImplExt + AudioBaseSrcImpl {
     fn close(&self, src: &Self::Type) -> Result<(), LoggableError> {
         self.parent_close(src)
     }
@@ -200,7 +201,7 @@ impl<T: AudioSrcImpl> AudioSrcImplExt for T {
 
 unsafe impl<T: AudioSrcImpl> IsSubclassable<T> for AudioSrc {
     fn class_init(klass: &mut glib::Class<Self>) {
-        <gst_base::BaseSrc as IsSubclassable<T>>::class_init(klass);
+        Self::parent_class_init::<T>(klass);
         let klass = klass.as_mut();
         klass.close = Some(audiosrc_close::<T>);
         klass.delay = Some(audiosrc_delay::<T>);
@@ -210,17 +211,13 @@ unsafe impl<T: AudioSrcImpl> IsSubclassable<T> for AudioSrc {
         klass.read = Some(audiosrc_read::<T>);
         klass.reset = Some(audiosrc_reset::<T>);
     }
-
-    fn instance_init(instance: &mut glib::subclass::InitializingObject<T>) {
-        <gst_base::BaseSrc as IsSubclassable<T>>::instance_init(instance);
-    }
 }
 
 unsafe extern "C" fn audiosrc_close<T: AudioSrcImpl>(
     ptr: *mut ffi::GstAudioSrc,
 ) -> glib::ffi::gboolean {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<AudioSrc> = from_glib_borrow(ptr);
 
     gst::panic_to_error!(&wrap, imp.panicked(), false, {
@@ -237,7 +234,7 @@ unsafe extern "C" fn audiosrc_close<T: AudioSrcImpl>(
 
 unsafe extern "C" fn audiosrc_delay<T: AudioSrcImpl>(ptr: *mut ffi::GstAudioSrc) -> u32 {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<AudioSrc> = from_glib_borrow(ptr);
 
     gst::panic_to_error!(&wrap, imp.panicked(), 0, {
@@ -249,7 +246,7 @@ unsafe extern "C" fn audiosrc_open<T: AudioSrcImpl>(
     ptr: *mut ffi::GstAudioSrc,
 ) -> glib::ffi::gboolean {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<AudioSrc> = from_glib_borrow(ptr);
 
     gst::panic_to_error!(&wrap, imp.panicked(), false, {
@@ -269,7 +266,7 @@ unsafe extern "C" fn audiosrc_prepare<T: AudioSrcImpl>(
     spec: *mut ffi::GstAudioRingBufferSpec,
 ) -> glib::ffi::gboolean {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<AudioSrc> = from_glib_borrow(ptr);
 
     let spec = &mut *(spec as *mut AudioRingBufferSpec);
@@ -290,7 +287,7 @@ unsafe extern "C" fn audiosrc_unprepare<T: AudioSrcImpl>(
     ptr: *mut ffi::GstAudioSrc,
 ) -> glib::ffi::gboolean {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<AudioSrc> = from_glib_borrow(ptr);
 
     gst::panic_to_error!(&wrap, imp.panicked(), false, {
@@ -312,7 +309,7 @@ unsafe extern "C" fn audiosrc_read<T: AudioSrcImpl>(
     timestamp: *mut gst::ffi::GstClockTime,
 ) -> u32 {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<AudioSrc> = from_glib_borrow(ptr);
     let data_slice = std::slice::from_raw_parts_mut(data as *mut u8, length as usize);
 
@@ -328,7 +325,7 @@ unsafe extern "C" fn audiosrc_read<T: AudioSrcImpl>(
 
 unsafe extern "C" fn audiosrc_reset<T: AudioSrcImpl>(ptr: *mut ffi::GstAudioSrc) {
     let instance = &*(ptr as *mut T::Instance);
-    let imp = instance.impl_();
+    let imp = instance.imp();
     let wrap: Borrowed<AudioSrc> = from_glib_borrow(ptr);
 
     gst::panic_to_error!(&wrap, imp.panicked(), (), {
